import { select } from 'd3';
import topojson from 'topojson-client';
import { map } from './map';

const usAtlasURL =
  'https://unpkg.com/us-atlas@3.0.1/states-10m.json';

export const main = (container, { state, setState }) => {
  const width = window.innerWidth;
  const height = window.innerHeight;

  const svg = select(container)
    .selectAll('svg')
    .data([null])
    .join('svg')
    .attr('width', width)
    .attr('height', height);

  // state.data could be:
  // * undefined
  // * 'LOADING'
  // * An array of objects
  const { data } = state;

  if (data && data !== 'LOADING') {
    svg.call(map, {
      data,
    });
  }

  if (data === undefined) {
    setState((state) => ({
      ...state,
      data: 'LOADING',
    }));
    fetch(usAtlasURL)
      .then((response) => response.json())
      .then((topoJSONData) => {
        const data = topojson.feature(
          topoJSONData,
          'states',
        );
        setState((state) => ({
          ...state,
          data,
        }));
      });
  }
};
